summaryrefslogtreecommitdiff
path: root/src/map/pet.c
diff options
context:
space:
mode:
authorHaru <haru@dotalux.com>2018-07-25 03:22:55 +0200
committerGitHub <noreply@github.com>2018-07-25 03:22:55 +0200
commited988911d28ddfa64e1340389a818e94785f2cba (patch)
treec55c3c678469fe724c1e747f7670d75d11ff0539 /src/map/pet.c
parent504ad2ca7d6ef4923093f74ac2afd5fc1bd39fd1 (diff)
parentc64b3517fb085e34f6c3c2ab83a3290b1726fc95 (diff)
downloadhercules-ed988911d28ddfa64e1340389a818e94785f2cba.tar.gz
hercules-ed988911d28ddfa64e1340389a818e94785f2cba.tar.bz2
hercules-ed988911d28ddfa64e1340389a818e94785f2cba.tar.xz
hercules-ed988911d28ddfa64e1340389a818e94785f2cba.zip
Merge pull request #2136 from Asheraf/petevofix
Pet evolution bug fixes
Diffstat (limited to 'src/map/pet.c')
-rw-r--r--src/map/pet.c14
1 files changed, 10 insertions, 4 deletions
diff --git a/src/map/pet.c b/src/map/pet.c
index e544905c0..d1d8a5a33 100644
--- a/src/map/pet.c
+++ b/src/map/pet.c
@@ -345,10 +345,13 @@ static int pet_return_egg(struct map_session_data *sd, struct pet_data *pd)
pd->pet.pet_id == MakeDWord(sd->status.inventory[i].card[1], sd->status.inventory[i].card[2]));
if (i != MAX_INVENTORY) {
- sd->status.inventory[i].identify = 1;
+ sd->status.inventory[i].attribute &= ~ATTR_BROKEN;
sd->status.inventory[i].bound = IBT_NONE;
}
-
+#if PACKETVER >= 20180704
+ clif->inventorylist(sd);
+ clif->send_petdata(sd, pd, 6, 0);
+#endif
pd->pet.incubate = 1;
unit->free(&pd->bl,CLR_OUTSIGHT);
@@ -462,6 +465,9 @@ static int pet_birth_process(struct map_session_data *sd, struct s_pet *petinfo)
clif->spawn(&sd->pd->bl);
clif->send_petdata(sd,sd->pd, 0,0);
clif->send_petdata(sd,sd->pd, 5,battle_config.pet_hair_style);
+#if PACKETVER >= 20180704
+ clif->send_petdata(sd, sd->pd, 6, 1);
+#endif
clif->send_petdata(NULL, sd->pd, 3, sd->pd->vd.head_bottom);
clif->send_petstatus(sd);
}
@@ -496,8 +502,8 @@ static int pet_recv_petdata(int account_id, struct s_pet *p, int flag)
if (!pet->birth_process(sd,p)) {
- // Pet Evolution, Hide the egg by setting identify to 0 [Dastgir/Hercules]
- sd->status.inventory[i].identify = 0;
+ // Pet Evolution, Hide the egg by setting broken attribute (0x2) [Asheraf]
+ sd->status.inventory[i].attribute |= ATTR_BROKEN;
// bind the egg to the character to avoid moving it via forged packets [Asheraf]
sd->status.inventory[i].bound = IBT_CHARACTER;
}